( cd opt/kde/share/doc/HTML/pt_BR/koffice ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/koffice ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kchart ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kchart ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kformula ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kformula ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kivio ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kivio ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/koshell ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/koshell ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kpresenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kpresenter ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kspread ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kspread ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kugar ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kugar ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kword ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kword ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/thesaurus ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/thesaurus ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
